## $Id: container.py 7256 2011-12-03 05:46:52Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Containers for students.
"""
import grok
from waeup.sirp.students.interfaces import (
    IStudentsContainer, IStudent)
from waeup.sirp.utils.helpers import get_current_principal
from waeup.sirp.utils.logger import Logger

class StudentsContainer(grok.Container, Logger):
    """
    The node containing the student models
    """

    grok.implements(IStudentsContainer)

    def archive(self, id=None):
        raise NotImplementedError()

    def clear(self, id=None, archive=True):
        raise NotImplementedError()

    def addStudent(self, student):
        """Add a student with subcontainers.
        """
        if not IStudent.providedBy(student):
            raise TypeError(
                'StudentsContainers contain only IStudent instances')
        self[student.student_id] = student
        return

    logger_name = 'waeup.sirp.${sitename}.students'
    logger_filename = 'students.log'

    def logger_info(self, ob_class, target, comment=None):
        """Get the logger's info method.
        """
        user = get_current_principal()
        if user is None:
            # In tests we do not necessarily have a logged on principal
            return
        user = user.id
        self.logger.info('%s - %s - %s - %s' % (
                user, ob_class, target, comment))
        return
